* REPLICATION FILE FOR COLGAN WEEKS IO 2014

log using ColganWeeksIORep, replace
set more off, perm
 
* Contents:

* MAIN TABLES:
   * TABLE 1 - POSTREV10 DYADIC 
   * TABLE 2 - POSTREV10 MONADIC 
   * TABLE 3 - REV LEADERS DYADIC 
   * TABLE 4 - REV LEADERS MONADIC 
   * TABLE 5 - RELATIONSHIP BETWEEN REVOLUTION AND PERSONALIST REGIMES 
   
   * FIGURE 1 - CLARIFY REV10 DYADIC 
   * FIGURE 2 - PERSONALIST REGIMES ENSCONCE REVOLUTIONARY LEADERS 
   * FIGURE 3 - RELATIONSHIP BETWEEN REVOLUTION, PERSONALISM, AND CONFLICT 
   
* APPENDIX: 
  * FIGURE A-1 - Total conflict initiation as a function of a revolutionary leader's tenure in office (MONADIC DATASET) 
  * TABLE A-1 - MIDs Initiated by year since a revolution (MONADIC DATASET) 
  * TABLES A.1.1-A.3.8 - Robustness checks of tables 1 and 3 (DYADIC DATASET)

* ADDITIONAL ROBUSTNESS CHECKS MENTIONED IN PAPER


***********************************************
************* MAIN TABLES *********************
***********************************************

**********************************
*** Table 1 - POSTREV10 DYADIC ***
**********************************

use ColganWeeksDyadic-public.dta, clear

	* POST-REV PERIOD
	* test of rev10, pers10, revpers10 

	* 1.1 - all MIDs, all revs
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.3 - all MIDs, unam revs
logit  mzinit revpers10_unam_lag1 rev10_unam_lag1 pers10_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_unam_lag1 rev10_unam_lag1, equal
	* subst effects
di exp(_b[revpers10_unam_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_lag1]-_b[rev10_unam_lag1]) // revpers10 vs rev10

	* 1.4 - fatal MIDs, unam  revs 
logit  mzinitfatalmid revpers10_unam_lag1 rev10_unam_lag1 pers10_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_unam_lag1 rev10_unam_lag1, equal
	* subst effects
di exp(_b[revpers10_unam_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_lag1]-_b[rev10_unam_lag1]) // revpers10 vs rev10



**********************************
*** TABLE 2: POSTREV10 MONADIC ***
**********************************

use ColganWeeksMonadic-public.dta, clear

table rev10 revpers10, c(m initmid)
table pers10 revpers10, c(m initmid)

	* Model 2.1 - All MIDs, all Revs
	* nbreg
nbreg initmid revpers10_lag rev10_lag pers10_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev10_lag revpers10_lag, equal
outreg2 using Table2, replace dec(2)
	* subst effects
di exp(_b[revpers10_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_lag]-_b[rev10_lag]) // revpers10 vs rev10

/*
	* zinb
	* kept splines only in model that predicts 0's
zinb initmid revpers10_lag rev10_lag pers10_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag, inflate(rev10_lag pers10_lag revpers10_lag total_lag cap_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*, cluster(ccode) 
testparm rev10_lag revpers10_lag, equal
*/

	* Model 2.2 - Fatal MIDs, all Revs
nbreg initfatalmid revpers10_lag rev10_lag pers10_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm rev10_lag revpers10_lag, equal
outreg2 using Table2, append dec(2)
	* subst effects
di exp(_b[revpers10_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_lag]-_b[rev10_lag]) // revpers10 vs rev10

/*
	* zinb
	* kept splines only in model that predicts 0's
zinb initfatalmid revpers10_lag rev10_lag pers10_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag, inflate(rev10_lag pers10_lag revpers10_lag total_lag cap_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*) cluster(ccode) 
testparm rev10_lag revpers10_lag, equal
*/

	* Model 2.3 - All MIDs, Unamb Revs
	* nbreg
nbreg initmid revpers10_unam_lag rev10_unam_lag pers10_unam_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev10_unam_lag revpers10_unam_lag, equal
outreg2 using Table2, append dec(2)
    * subst effects
di exp(_b[revpers10_unam_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_lag]-_b[rev10_unam_lag]) // revpers10 vs rev10

/*
	* zinb
	* kept splines only in model that predicts 0's
zinb initmid revpers10_unam_lag rev10_unam_lag pers10_unam_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag, inflate(rev10_lag pers10_lag revpers10_lag total_lag cap_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*) cluster(ccode) 
testparm rev10_unam_lag revpers10_unam_lag, equal
*/

	* Model 2.4 - Fatal MIDs, Unamb Rev
nbreg initfatalmid revpers10_unam_lag rev10_unam_lag pers10_unam_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm revpers10_unam_lag rev10_unam_lag, equal
    * subst effects
di exp(_b[revpers10_unam_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_lag]-_b[rev10_unam_lag]) // revpers10 vs rev10
outreg2 using Table2, append dec(2)


************************************
*** Table 3 - REV LEADERS DYADIC ***
************************************

use ColganWeeksDyadic-public.dta, clear

	* 3.1: all MIDs, all revols, with splines
logit mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers10 compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers10 vs rev10


	* 3.2: fatal MIDs, all revols, with splines
logit mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers10 compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers10 vs rev10


	* 3.3: all MIDs, unam revols, with splines
logit mzinit revpers_unam_lag1 rev_unam_lag1 pers_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_unam_lag1 rev_unam_lag1, equal
	* subst effects
di exp(_b[revpers_unam_lag1]) // revpers10 compared to baseline
di exp(_b[revpers_unam_lag1]-_b[rev_unam_lag1]) // revpers10 vs rev10


	* 3.4: fatal MIDs, all revols, with splines
logit mzinitfatalmid revpers_unam_lag1 rev_unam_lag1 pers_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_unam_lag1 rev_unam_lag1, equal
	* subst effects
di exp(_b[revpers_unam_lag1]) // revpers10 compared to baseline
di exp(_b[revpers_unam_lag1]-_b[rev_unam_lag1]) // revpers10 vs rev10



*************************************
*** TABLE 4 - REV LEADERS MONADIC ***
*************************************

use ColganWeeksMonadic-public.dta, clear

	* Model 4.1 - All MIDs, all Revs
	* nbreg
nbreg initmid revpers_lag rev_lag pers_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev_lag revpers_lag, equal
outreg2 using Table3, replace dec(2)
	* subst effects
di exp(_b[revpers_lag]) // revpers10 compared to baseline
di exp(_b[revpers_lag]-_b[rev_lag]) // revpers10 vs rev10

/*
	* zinb
	* kept splines only in model that predicts 0's
zinb initmid revpers_lag rev_lag pers_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag, inflate(rev_lag pers_lag revpers_lag total_lag cap_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*) cluster(ccode) 
testparm rev_lag revpers_lag, equal
*/

	* Model 4.2 - Fatal MIDs, all Revs
nbreg initfatalmid revpers_lag rev_lag pers_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm rev_lag revpers_lag, equal
outreg2 using Table3, append dec(2)
	* subst effects
di exp(_b[revpers_lag]) // revpers10 compared to baseline
di exp(_b[revpers_lag]-_b[rev_lag]) // revpers10 vs rev10

/*
	* zinb
	* kept splines only in model that predicts 0's
zinb initfatalmid revpers_lag rev_lag pers_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag, inflate(rev_lag pers_lag revpers_lag total_lag cap_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*) cluster(ccode) 
testparm rev_lag revpers_lag, equal
*/

	* Model 4.3 - All MIDs, Unamb Revs
	* nbreg
nbreg initmid revpers_unam_lag rev_unam_lag pers_unam_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev_unam_lag revpers_unam_lag, equal
outreg2 using Table3, append dec(2)
	* subst effects
di exp(_b[revpers_unam_lag]) // revpers10 compared to baseline
di exp(_b[revpers_unam_lag]-_b[rev_unam_lag]) // revpers10 vs rev10

/*
	* zinb
	* kept splines only in model that predicts 0's
zinb initmid revpers_unam_lag rev_unam_lag pers_unam_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag, inflate(rev_lag pers_lag revpers_lag total_lag cap_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*) cluster(ccode) 
testparm rev_unam_lag revpers_unam_lag, equal
*/

	* model 4.4 - Fatal MIDs, Unamb Rev
nbreg initfatalmid revpers_unam_lag rev_unam_lag pers_unam_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm revpers_unam_lag rev_unam_lag, equal
outreg2 using Table3, append dec(2)
	* subst effects
di exp(_b[revpers_unam_lag]) // revpers10 compared to baseline
di exp(_b[revpers_unam_lag]-_b[rev_unam_lag]) // revpers10 vs rev10



****************************************************
*** Table 5: REVOLUTIONS AND PERSONALIST REGIMES ***
****************************************************

use ColganWeeksMonadic-public.dta, clear 

total startrev 

bys ccode (year): gen personalist_lead=personalist[_n+1]

** Of the 74 revolutions, we lose 12 due to missing pre-values (many of them were monarchies)
gen sample=0
replace sample=1 if startrev==1 & personalist_lag!=. & personalist_lead!=.

* Table 5, Column 1
tab personalist_lag if startrev==1 & sample==1
sum personalist_lag if startrev==1 & year>1946 & sample==1

* Table 5, Column 2
tab personalist_lead if startrev==1 & year>1946 & sample==1
sum personalist_lead if startrev==1 & year>1946 & sample==1
bys ccode (year): gen persdiff=personalist_lead-personalist_lag

tab personalist_lag personalist_lead if startrev==1 & year>1946, row
tab personalist_lag personalist_lead if startrev==1 & year>1946, chi2
reg persdiff if year>1946 & startrev==1

* Table 5, Column 3
tab personalist if postrev10==0 

* Table 5, Column 4
tab personalist if postrev10==1

ttest personalist, by(postrev10)

* Table 5, Column 5
tab personalist if postrev10!=.



************************************************************
********* FIGURE 1 - MID INITIATION USING CLARIFY **********
************************************************************

use ColganWeeksDyadic-public.dta, clear

logit mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
tab revpers10_lag1 if e(sample)
tab rev10_lag1 if e(sample) 
tab pers10_lag1 if e(sample)

sum cap_1_lag if e(sample), d
sum cap_2_lag if e(sample) & minmaj_lag==1, d
sum logdist_lag if contigdum_lag==1 & e(sample), d


* Figure 1a - all MIDs
set seed 20121221 // so that reps are identical 
estsimp logit mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)

setx median
setx minmaj_lag 1
setx cap_1_lag .03 // 95 %ile in sample
setx cap_2_lag .10 // median when minmaj_lag==1
setx initshare_lag .33 // to be consistent with above two values
setx contigdum_lag 1
setx logdist_lag 0

simqi // not pers and not rev
setx pers10_lag1 1 // pers but not rev
simqi
setx pers10_lag1 0 rev10_lag1 1 // rev but not pers
simqi
setx rev10_lag1 0 revpers10_lag1 1 // rev and pers
simqi

* Figure 1b - fatal MIDs
drop b1-b22
set seed 20121221 // so that reps are identical 
estsimp logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)

setx median
setx minmaj_lag 1
setx cap_1_lag .03 // 95 %ile in sample
setx cap_2_lag .10 // median when minmaj_lag==1
setx initshare_lag .33 // to be consistent with above two values
setx contigdum_lag 1
setx logdist_lag 0

simqi // not pers and not rev
setx pers10_lag1 1 // pers but not rev
simqi
setx pers10_lag1 0 rev10_lag1 1 // rev but not pers
simqi
setx rev10_lag1 0 revpers10_lag1 1 // rev and pers
simqi


**********************************************************
*** FIGURE 2: PERSONALIST REGIMES ENSCONCE REV LEADERS ***
**********************************************************

clear
use ColganWeeksMonadic-public.dta, clear 

drop if year<1946 // don't have pers data for that year so don't want to use 1944 or 1945 as first years
bys ccode leader: egen uniqtag = rank(year)

table personalist if uniqtag==1, c(m tenure n tenure) // Column 1
ttest tenure if uniqtag==1, by(personalist)

table personalist if postrev10==1 & uniqtag==1, c(m tenure n tenure) // Column 2

table personalist if uniqtag==1 & revleader==1, c(m tenure n tenure) // Column 3 - all rev leaders
ttest tenure if uniqtag==1 & revleader==1, by(personalist) 

* footnote
table personalist if uniqtag==1 & polity4<6 & polity4!=., c(m tenure n tenure)

* are personalist regimes more likely to have revolutionary leaders in power in the years after a rev?
* yes
tab personalist if postrev10==1, sum(revleader)
tab personalist revleader if postrev10==1, chi2



******************************************
*** FIGURE 3 - REV, PERS, AND CONFLICT ***
******************************************

clear
use ColganWeeksMonadic-public.dta, clear 

tab revpers10, sum(initmid)
tab rev10, sum(initmid)

* browsed and then added the number of individual MIDs in Excel
browse abbrev year leader initmid if postrev10_lag==1 & initmid>0
browse abbrev year leader initmid if revpers10_lag==1 & initmid>0 // personalists only
browse abbrev year leader initmid if rev10_lag==1 & initmid>0 // nonpersonalists only

* to see distributions
tab initmid if revpers10==1
tab initmid if rev10==1 


* APPENDIX

***************************
*** APPENDIX FIGURE A-1 ***
***************************

use ColganWeeksMonadic-public.dta, clear 

label var tenure "Years in Office"
bys ccode leader: egen midtotal = total(initmid)
label var midtotal "Total Number of MIDs Initiated"
list leader midtotal tenure if revpers10==1 & startrev==1

graph twoway (scatter midtotal tenure if revpers10==1, xsca(r(0 50)) ysca(r(0 65))) (lfit midtotal tenure if revpers10==1) // Figure A-1

graph twoway (scatter midtotal tenure) (lfit midtotal tenure)
graph twoway (scatter midtotal tenure if rev10==1, xsca(r(0 50)) ysca(r(0 65))) (lfit midtotal tenure if rev10==1)


**************************
*** APPENDIX TABLE A-1 ***
**************************

use ColganWeeksMonadic-public.dta, clear 

gen timesincerevol = lastrev-1
replace timesincerevol = 0 if (rev10==0 & revpers10==0 | postrev10==.) 
table timesincerevol if revpers10 ==1, c(m initmid) // Table A-1

table timesincerevol if revpers10 ==1, c(m initmid n initmid)
table timesincerevol if revpers10 ==1, c(m initmid n initmid sem initmid)
table timesincerevol if rev10 ==1, c(m initmid n initmid sem initmid)
table timesincerevol if rev10 ==1, c(m initmid n initmid)


**********************************
***** APPENDIX TABLE A.1.1 *******
**********************************

use ColganWeeksDyadic-public.dta, clear 

	* 1. USE THE WEEKS 2012 DATA ONLY (NO FILLING IN WITH GWF)
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_jlw_lag1 rev10_jlw_lag1 pers10_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_jlw_lag1 rev10_jlw_lag1, equal
	* subst effects
di exp(_b[revpers10_jlw_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_jlw_lag1]-_b[rev10_jlw_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers10_jlw_lag1 rev10_jlw_lag1 pers10_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_jlw_lag1 rev10_jlw_lag1, equal
	* subst effects
di exp(_b[revpers10_jlw_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_jlw_lag1]-_b[rev10_jlw_lag1]) // revpers10 vs rev10

	* 1.3A - all MIDs, unam revs
logit  mzinit revpers10_unam_jlw_lag1 rev10_unam_jlw_lag1 pers10_unam_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_unam_jlw_lag1 rev10_unam_jlw_lag1, equal
	* subst effects
di exp(_b[revpers10_unam_jlw_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_jlw_lag1]-_b[rev10_unam_jlw_lag1]) // revpers10 vs rev10

	* 1.4A - fatal MIDs, unam  revs
logit  mzinitfatalmid revpers10_unam_jlw_lag1 rev10_unam_jlw_lag1 pers10_unam_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_unam_jlw_lag1 rev10_unam_jlw_lag1, equal
	* subst effects
di exp(_b[revpers10_unam_jlw_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_jlw_lag1]-_b[rev10_unam_jlw_lag1]) // revpers10 vs rev10


*********************************
***** APPENDIX TABLE A.1.2 ******
*********************************

	* 2. ALTERNATIVE TIME CUTOFFS FOR THE POST-REVOLUTIONARY PERIOD
			* A: 8 YEARS POST-REV
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers8_lag1 rev8_lag1 pers8_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers8_lag1 rev8_lag1, equal
	* subst effects
di exp(_b[revpers8_lag1]) // revpers8 compared to baseline
di exp(_b[revpers8_lag1]-_b[rev8_lag1]) // revpers8 vs rev8

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers8_lag1 rev8_lag1 pers8_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers8_lag1 rev8_lag1, equal
	* subst effects
di exp(_b[revpers8_lag1]) // revpers8 compared to baseline
di exp(_b[revpers8_lag1]-_b[rev8_lag1]) // revpers8 vs rev8

			* B: 12 YEARS POST-REV
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers12_lag1 rev12_lag1 pers12_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers12_lag1 rev12_lag1, equal
	* subst effects
di exp(_b[revpers12_lag1]) // revpers12 compared to baseline
di exp(_b[revpers12_lag1]-_b[rev12_lag1]) // revpers12 vs rev12

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers12_lag1 rev12_lag1 pers12_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers12_lag1 rev12_lag1, equal
	* subst effects
di exp(_b[revpers12_lag1]) // revpers12 compared to baseline
di exp(_b[revpers12_lag1]-_b[rev12_lag1]) // revpers12 vs rev12


*********************************
***** APPENDIX TABLE A.1.3 ******
*********************************

	* 3. DROP TRADE 
	* 1.1 - all MIDs, all revs
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


	* 4. CONTROL FOR DEPEND1 RATHER THAN DEPENDLOW (R1)
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag depend1_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag depend1_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


*********************************
***** APPENDIX TABLE A.1.4 ******
*********************************

	* 5. CONTROL FOR CIVILWARLOW
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwarlow1_lag civilwarlow2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwarlow1_lag civilwarlow2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	
	* 6. ADD POLITY SCORES
recode polity1_lag -99=. -88=. -77=. -66=.
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 polity1_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag  civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 polity1_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


*********************************
***** APPENDIX TABLE A.1.5 ******
*********************************

	* 7. CONTROL FOR REGION
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag region1d* pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag region1d* pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 8. ALTERNATE PERSONALISM THRESHOLD
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_alt_lag1 rev10_alt_lag1 pers10_alt_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_alt_lag1 rev10_alt_lag1, equal
	* subst effects
di exp(_b[revpers10_alt_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_alt_lag1]-_b[rev10_alt_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_alt_lag1 rev10_alt_lag1 pers10_alt_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_alt_lag1 rev10_alt_lag1, equal
	* subst effects
di exp(_b[revpers10_alt_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_alt_lag1]-_b[rev10_alt_lag1]) // revpers10 vs rev10


*********************************
***** APPENDIX TABLE A.1.6 ******
*********************************

	*  9. DROP CHINA AND USSR AND IRAN ALL AT ONCE 
	* 1.1 - all MIDs, all revs
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits* if ccode1!=365 & ccode1!=710 & ccode1!=630, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids* if ccode1!=365 & ccode1!=710 & ccode1!=630, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


    * 10. DROP TANKER WARS
	* 1.1 - all MIDs, all revs 
logit  mzinitnotank revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitnotank pcyrsmzinitnotanks*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


 	* 11. DEADLY MIDS
	* coded as: initiated MID against a dyad member in the context of a dispute that involved more than 25 deaths (26 or more)
	* ie could initiate against another country and neither country suffered deaths, as long as the overall MID involved 26 or more deaths
	* (ex: US mzinit25 against USR in 1954, mid #50)
logit mzinit25 revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit25 pcyrsmzinit25s*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


*********************************
***** APPENDIX TABLE A.1.7 ******
*********************************

	* 12. DROP THE FOUNDING LEADERS
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits* if foundingleader1_lag==0, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids* if foundingleader1_lag==0, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10


	* 13. DROP OBSERVATIONS FROM FIRST 3 YEARS AFTER REVOLUTION TO ENSURE REVERSE CAUSATION NOT DRIVING RESULTS
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits* if postrev31!=1, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs (with splines - lag the other controls)
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids* if postrev31!=1, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10
	

*********************************
***** APPENDIX TABLE A.1.8 ******
*********************************

	* 14. USING TIME, TIME2, TIME3
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag time time2 time3, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag timef timef2 timef3, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.3 - all MIDs, unam revs 
logit  mzinit revpers10_unam_lag1 rev10_unam_lag1 pers10_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag time time2 time3, robust cluster(dirdyadid)
testparm revpers10_unam_lag1 rev10_unam_lag1, equal
	* subst effects
di exp(_b[revpers10_unam_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_lag1]-_b[rev10_unam_lag1]) // revpers10 vs rev10

	* 1.4 - fatal MIDs, unam  revs 
logit  mzinitfatalmid revpers10_unam_lag1 rev10_unam_lag1 pers10_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag timef timef2 timef3, robust cluster(dirdyadid)
testparm revpers10_unam_lag1 rev10_unam_lag1, equal
	* subst effects
di exp(_b[revpers10_unam_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_lag1]-_b[rev10_unam_lag1]) // revpers10 vs rev10


*********************************
***** APPENDIX TABLE A.1.9 ******
*********************************

*	14. PREVIOUS EXPERIENCE WITH DEMOCRACY
	* First, test for the effect of the number of previous democratic years
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 demcount_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
outreg2 using Table1A.9, replace dec(2)
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 demcount_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
outreg2 using Table1A.9, append dec(2)
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* Second, test for the effect of the number of previous democratic experiences (of any time length)
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers10_lag1 rev10_lag1 pers10_lag1 prevdem_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
outreg2 using Table1A.9, append dec(2)
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers10_lag1 rev10_lag1 pers10_lag1 prevdem_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers10_lag1 rev10_lag1, equal
outreg2 using Table1A.9, append dec(2)
	* subst effects
di exp(_b[revpers10_lag1]) // revpers10 compared to baseline
di exp(_b[revpers10_lag1]-_b[rev10_lag1]) // revpers10 vs rev10



*********************************
***** APPENDIX TABLE A.3.1 ******
*********************************

	* 1. USE THE WEEKS 2012 DATA ONLY (NO FILLING IN WITH GWF)
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_jlw_lag1 rev_jlw_lag1 pers_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_jlw_lag1 rev_jlw_lag1, equal
	* subst effects
di exp(_b[revpers_jlw_lag1]) // revpers compared to baseline
di exp(_b[revpers_jlw_lag1]-_b[rev_jlw_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs (with splines - lag the other controls)
logit  mzinitfatalmid revpers_jlw_lag1 rev_jlw_lag1 pers_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_jlw_lag1 rev_jlw_lag1, equal
	* subst effects
di exp(_b[revpers_jlw_lag1]) // revpers compared to baseline
di exp(_b[revpers_jlw_lag1]-_b[rev_jlw_lag1]) // revpers vs rev

	* 3.3 - all MIDs, unam revs (with splines - lag the other controls)
logit  mzinit revpers_unam_jlw_lag1 rev_unam_jlw_lag1 pers_unam_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_unam_jlw_lag1 rev_unam_jlw_lag1, equal
	* subst effects
di exp(_b[revpers_unam_jlw_lag1]) // revpers compared to baseline
di exp(_b[revpers_unam_jlw_lag1]-_b[rev_unam_jlw_lag1]) // revpers vs rev

	* 3.4 - fatal MIDs, unam  revs (with splines - lag the other controls)
logit  mzinitfatalmid revpers_unam_jlw_lag1 rev_unam_jlw_lag1 pers_unam_jlw_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_unam_jlw_lag1 rev_unam_jlw_lag1, equal
	* subst effects
di exp(_b[revpers_unam_jlw_lag1]) // revpers compared to baseline
di exp(_b[revpers_unam_jlw_lag1]-_b[rev_unam_jlw_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.2 ******
*********************************

	* 2. DROP TRADE
	* 3.1 - all MIDs, all revs
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


	* 3. CONTROL FOR DEPEND1 RATHER THAN DEPENDLOW (R1)
	* 3.1 - all MIDs, all revs
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag depend1_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag depend1_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.3 ******
*********************************

	* 4. CONTROL FOR CIVILWARLOW
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwarlow1_lag civilwarlow2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwarlow1_lag civilwarlow2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	
	* 5. ADD POLITY SCORES
recode polity1_lag -99=. -88=. -77=. -66=.
	* 3.1 - all MIDs, all revs
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 polity1_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 polity1_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
outreg2 using Table3A.3, append dec(2)
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.4 ******
*********************************

	* 6. CONTROL FOR REGION
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag region1d* pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag region1d* pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


	* 7. ALTERNATE PERSONALISM THRESHOLD
	* 1. USE THE WEEKS 2012 DATA ONLY (NO FILLING IN WITH GWF)
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_alt_lag1 rev_alt_lag1 pers_alt_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_alt_lag1 rev_alt_lag1, equal
	* subst effects
di exp(_b[revpers_alt_lag1]) // revpers compared to baseline
di exp(_b[revpers_alt_lag1]-_b[rev_alt_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_alt_lag1 rev_alt_lag1 pers_alt_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_alt_lag1 rev_alt_lag1, equal
	* subst effects
di exp(_b[revpers_alt_lag1]) // revpers compared to baseline
di exp(_b[revpers_alt_lag1]-_b[rev_alt_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.5 ******
*********************************

	*  8. DROP USSR, CHINA, AND IRAN ALL AT ONCE 
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits* if ccode1!=365 & ccode1!=710 & ccode1!=630, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids* if ccode1!=365 & ccode1!=710 & ccode1!=630, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	*  9. DROP TANKER WARS
	* 3.1 - all MIDs, all revs 
logit  mzinitnotank revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitnotank pcyrsmzinitnotanks* if ccode1!=645 & ccode1!=630, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

 	* 10. DEADLY MIDS
	* coded as: initiated MID against a dyad member in the context of a dispute that involved more than 25 deaths (26 or more)
	* ie could initiate against another country and neither country suffered deaths, as long as the overall MID involved 26 or more deaths
	* (ex: US mzinit25 against USR in 1954, mid #50)
logit mzinit25 revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit25 pcyrsmzinit25s*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.6 ******
*********************************

	* 11. DROP THE FOUNDING LEADERS
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits* if foundingleader1_lag==0, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids* if foundingleader1_lag==0, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


	* 12. DROP OBSERVATIONS FROM FIRST 3 YEARS AFTER REVOLUTION TO ENSURE REVERSE CAUSATION NOT DRIVING RESULTS
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits* if postrev31!=1, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids* if postrev31!=1, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.7 ******
*********************************

	* 13. USE TIME, TIME2, TIME3
	* 3.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag time time2 time3, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag timef timef2 timef3, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 3.3: all MIDs, unam revols, with splines
logit mzinit revpers_unam_lag1 rev_unam_lag1 pers_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_unam_lag1 rev_unam_lag1, equal
	* subst effects
di exp(_b[revpers_unam_lag1]) // revpers compared to baseline
di exp(_b[revpers_unam_lag1]-_b[rev_unam_lag1]) // revpers vs rev

	* 3.4: fatal MIDs, all revols, with splines
logit mzinitfatalmid revpers_unam_lag1 rev_unam_lag1 pers_unam_lag1 cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_unam_lag1 rev_unam_lag1, equal
	* subst effects
di exp(_b[revpers_unam_lag1]) // revpers compared to baseline
di exp(_b[revpers_unam_lag1]-_b[rev_unam_lag1]) // revpers vs rev


*********************************
***** APPENDIX TABLE A.3.8 ******
*********************************

*	14. PREVIOUS EXPERIENCE WITH DEMOCRACY
	* First, test for the effect of the number of previous democratic years
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 demcount_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 1.2 - fatal MIDs, all revs
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 demcount_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* Second, test for the effect of the number of previous democratic experiences (of any time length)
	* 1.1 - all MIDs, all revs 
logit  mzinit revpers_lag1 rev_lag1 pers_lag1 prevdem_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinit pcyrsmzinits*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev

	* 1.2 - fatal MIDs, all revs 
logit  mzinitfatalmid revpers_lag1 rev_lag1 pers_lag1 prevdem_lag cap_1_lag cap_2_lag initshare_lag dependlow_lag civilwar_1_lag civilwar_2_lag majmaj_lag minmaj_lag majmin_lag contigdum_lag logdist_lag s_wt_glo_lag s_lead_1_lag s_lead_2_lag pcyrsmzinitfatalmid pcyrsmzinitfatalmids*, robust cluster(dirdyadid)
testparm revpers_lag1 rev_lag1, equal
	* subst effects
di exp(_b[revpers_lag1]) // revpers compared to baseline
di exp(_b[revpers_lag1]-_b[rev_lag1]) // revpers vs rev



* ADDITIONAL ROBUSTNESS CHECKS

****************************************************
*** ROBUSTNESS FOR TABLE 2: SHOW WITH WEEKS-ONLY ***
****************************************************

use ColganWeeksMonadic-public.dta, clear

	* Model 2.1 - All MIDs, all Revs
	* nbreg
nbreg initmid revpers10_jlw_lag rev10_jlw_lag pers10_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev10_jlw_lag revpers10_jlw_lag, equal
outreg2 using Table2A, replace dec(2)
	* subst effects
di exp(_b[revpers10_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_jlw_lag]-_b[rev10_jlw_lag]) // revpers10 vs rev10

	* Model 2.2 - Fatal MIDs, all Revs
nbreg initfatalmid revpers10_jlw_lag rev10_jlw_lag pers10_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm rev10_jlw_lag revpers10_jlw_lag, equal
outreg2 using Table2A, append dec(2)
	* subst effects
di exp(_b[revpers10_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_jlw_lag]-_b[rev10_jlw_lag]) // revpers10 vs rev10

	* Model 2.3 - All MIDs, Unamb Revs
	* nbreg
nbreg initmid revpers10_unam_jlw_lag rev10_unam_jlw_lag pers10_unam_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev10_unam_jlw_lag revpers10_unam_jlw_lag, equal
outreg2 using Table2A, append dec(2)
    * subst effects
di exp(_b[revpers10_unam_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_jlw_lag]-_b[rev10_unam_jlw_lag]) // revpers10 vs rev10

	* Model 2.4 - Fatal MIDs, Unamb Rev
nbreg initfatalmid revpers10_unam_jlw_lag rev10_unam_jlw_lag pers10_unam_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm revpers10_unam_jlw_lag rev10_unam_jlw_lag, equal
    * subst effects
di exp(_b[revpers10_unam_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers10_unam_jlw_lag]-_b[rev10_unam_jlw_lag]) // revpers10 vs rev10
outreg2 using Table2A, append dec(2)


****************************************************
*** ROBUSTNESS FOR TABLE 4: SHOW WITH WEEKS-ONLY ***
****************************************************

use ColganWeeksMonadic-public.dta

	* Model 2.1 - All MIDs, all Revs
	* nbreg
nbreg initmid revpers_jlw_lag rev_jlw_lag pers_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev_jlw_lag revpers_jlw_lag, equal
outreg2 using Table2A, replace dec(2)
	* subst effects
di exp(_b[revpers_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers_jlw_lag]-_b[rev_jlw_lag]) // revpers10 vs rev10

	* Model 2.2 - Fatal MIDs, all Revs
nbreg initfatalmid revpers_jlw_lag rev_jlw_lag pers_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm rev_jlw_lag revpers_jlw_lag, equal
outreg2 using Table2A, append dec(2)
	* subst effects
di exp(_b[revpers_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers_jlw_lag]-_b[rev_jlw_lag]) // revpers10 vs rev10

	* Model 2.3 - All MIDs, Unamb Revs
	* nbreg
nbreg initmid revpers_unam_jlw_lag rev_unam_jlw_lag pers_unam_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm rev_unam_jlw_lag revpers_unam_jlw_lag, equal
outreg2 using Table2A, append dec(2)
    * subst effects
di exp(_b[revpers_unam_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers_unam_jlw_lag]-_b[rev_unam_jlw_lag]) // revpers10 vs rev10

	* Model 2.4 - Fatal MIDs, Unamb Rev
nbreg initfatalmid revpers_unam_jlw_lag rev_unam_jlw_lag pers_unam_jlw_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitfatalmid pcyrsinitfatalmids*,  cluster(ccode)
testparm revpers_unam_jlw_lag rev_unam_jlw_lag, equal
    * subst effects
di exp(_b[revpers_unam_jlw_lag]) // revpers10 compared to baseline
di exp(_b[revpers_unam_jlw_lag]-_b[rev_unam_jlw_lag]) // revpers10 vs rev10
outreg2 using Table2A, append dec(2)


***************************************************************
******  Among post-rev states, revol predicts more MIDs  ******
***************************************************************

use ColganWeeksMonadic-public.dta

tab revleader_lag if postrev10==1, sum(initmid)

* rerun Model 2.1/4.1, only among revolutionaries
nbreg initmid revleader_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids* if postrev10_lag==1,  cluster(ccode)

* do this as part of a larger model rather than only 600 obs
gen postrev10_revleader_lag=postrev10_lag
replace postrev10_revleader_lag=0 if revleader_lag==0

gen postrev10_notrevleader_lag=postrev10_lag
replace postrev10_notrevleader_lag=0 if revleader_lag==1

nbreg initmid postrev10_notrevleader_lag postrev10_revleader_lag logopengled_lag total_lag cap_lag totalally_lag civilwar_lag majpow_lag pcyrsinitmid pcyrsinitmids*,  cluster(ccode)
testparm postrev10_revleader postrev10_notrevleader, equal



* ENDURING RIVALRIES
* DO RIVALRIES PREDICT INSTITUTIONS?

use ColganWeeksMonadic-public.dta, clear

bys ccode (year): gen personalist_lead=personalist[_n+1]
by ccode (year): gen persdiff=personalist_lead-personalist_lag

* Using Bennett data, compare number of rivalries to post-revolution regime type
tab personalist_lead rivnum if startrev==1 & year>1946, row // no appreciable difference when looking just at post-rev regime type
tab persdiff rivnum if startrev==1 & year>1946, row // those that transition TO personalism actually least likely to have rivalries
ologit persdiff rivnum if startrev==1 & year>1946 
tab personalist_lag rivnum if startrev==1 & year>1946, row // pre-rev personalism does predict rivalry, as our theory says


** Using Goertz and Diehl data, compare number of rivalries to post-revolution regime type
tab personalist_lead gdrivnum if startrev==1 & year>1946, row // no appreciable difference when looking just at post-rev regime type
tab persdiff gdrivnum if startrev==1 & year>1946, row // those that transition TO personalism actually least likely to have rivalries
ologit persdiff gdrivnum if startrev==1 & year>1946 
tab personalist_lag gdrivnum if startrev==1 & year>1946, row // pre-rev personalism does predict rivalry, as our theory says



log close



